==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1/ManagedClusterVersionFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ManagedClusterVersionFluent<A extends ManagedClusterVersionFluent<A>> extends BaseFluent<A>{
  public ManagedClusterVersionFluent() {
  }
  public ManagedClusterVersionFluent(ManagedClusterVersion instance) {
    instance = (instance != null ? instance : new ManagedClusterVersion());

    if (instance != null) {
      this.withKubernetes(instance.getKubernetes());
      this.withKubernetes(instance.getKubernetes());
    }
  }
  private String kubernetes;
  public String getKubernetes() {
    return this.kubernetes;
  }
  public A withKubernetes(String kubernetes) {
    this.kubernetes=kubernetes; return (A) this;
  }
  public boolean hasKubernetes() {
    return this.kubernetes != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ManagedClusterVersionFluent that = (ManagedClusterVersionFluent) o;
    if (!java.util.Objects.equals(kubernetes, that.kubernetes)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(kubernetes,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (kubernetes != null) { sb.append("kubernetes:"); sb.append(kubernetes); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1/ManagedClusterVersionFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ManagedClusterVersionFluent<A extends ManagedClusterVersionFluent<A>> extends BaseFluent<A>{
  public ManagedClusterVersionFluent() {
  }
  
  public ManagedClusterVersionFluent(ManagedClusterVersion instance) {
    this.copyInstance(instance);
  }
  private String kubernetes;
  
  protected void copyInstance(ManagedClusterVersion instance) {
    instance = (instance != null ? instance : new ManagedClusterVersion());
  
    if (instance != null) {
        this.withKubernetes(instance.getKubernetes());
        this.withKubernetes(instance.getKubernetes());
      }
  }
  
  public String getKubernetes() {
    return this.kubernetes;
  }
  
  public A withKubernetes(String kubernetes) {
    this.kubernetes=kubernetes; return (A) this;
  }
  
  public boolean hasKubernetes() {
    return this.kubernetes != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ManagedClusterVersionFluent that = (ManagedClusterVersionFluent) o;
    if (!java.util.Objects.equals(kubernetes, that.kubernetes)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(kubernetes,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (kubernetes != null) { sb.append("kubernetes:"); sb.append(kubernetes); }
    sb.append("}");
    return sb.toString();
  }
  

}
